@@ -17,11 +17,11 @@ class I3barRenderer(Renderer):
 		# We don’t need to explicitly reset attributes, so skip those calls
 		return ''
 
-	def hl(self, contents, fg=None, bg=None, attr=None):
+	def hl(self, contents, fg=None, bg=None, attrs=None):
 		segment = {
 			'full_text': contents,
 			'separator': False,
-			'separator_block_width': 0,  # no seperators
+			'separator_block_width': 0,  # no separators
 		}
 
 		if fg is not None:
@@ -29,9 +29,8 @@ class I3barRenderer(Renderer):
 				segment['color'] = '#{0:06x}'.format(fg[1])
 		if bg is not None:
 			if bg is not False and bg[1] is not False:
-				segment['background_color'] = '#{0:06x}'.format(bg[1])
-		# i3bar “pseudo json” requires one line at a time
-		return json.dumps(segment) + ',\n'
+				segment['background'] = '#{0:06x}'.format(bg[1])
+		return json.dumps(segment) + ','
 
 
 renderer = I3barRenderer
